==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/AttendeeBase.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.enums.AttendeeType;

@JsonPropertyOrder({
    "@odata.type", 
    "type"})
@JsonInclude(Include.NON_NULL)
public class AttendeeBase extends Recipient implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("type")
    protected AttendeeType type;

    protected AttendeeBase() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.attendeeBase";
    }

    @Property(name="type")
    @JsonIgnore
    public Optional<AttendeeType> getType() {
        return Optional.ofNullable(type);
    }

    public AttendeeBase withType(AttendeeType type) {
        AttendeeBase _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.attendeeBase");
        _x.type = type;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAttendeeBase() {
        return new Builder();
    }

    public static final class Builder {
        private EmailAddress emailAddress;
        private AttendeeType type;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder emailAddress(EmailAddress emailAddress) {
            this.emailAddress = emailAddress;
            this.changedFields = changedFields.add("emailAddress");
            return this;
        }

        public Builder type(AttendeeType type) {
            this.type = type;
            this.changedFields = changedFields.add("type");
            return this;
        }

        public AttendeeBase build() {
            AttendeeBase _x = new AttendeeBase();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.attendeeBase";
            _x.emailAddress = emailAddress;
            _x.type = type;
            return _x;
        }
    }

    private AttendeeBase _copy() {
        AttendeeBase _x = new AttendeeBase();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.emailAddress = emailAddress;
        _x.type = type;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AttendeeBase[");
        b.append("emailAddress=");
        b.append(this.emailAddress);
        b.append(", ");
        b.append("type=");
        b.append(this.type);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/AttendeeBase.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.enums.AttendeeType;

@JsonPropertyOrder({
    "@odata.type", 
    "type"})
@JsonInclude(Include.NON_NULL)
public class AttendeeBase extends Recipient implements ODataType {

    @JsonProperty("type")
    protected AttendeeType type;

    protected AttendeeBase() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.attendeeBase";
    }

    @Property(name="type")
    @JsonIgnore
    public Optional<AttendeeType> getType() {
        return Optional.ofNullable(type);
    }

    public AttendeeBase withType(AttendeeType type) {
        AttendeeBase _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.attendeeBase");
        _x.type = type;
        return _x;
    }

    public AttendeeBase withUnmappedField(String name, Object value) {
        AttendeeBase _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAttendeeBase() {
        return new Builder();
    }

    public static final class Builder {
        private EmailAddress emailAddress;
        private AttendeeType type;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder emailAddress(EmailAddress emailAddress) {
            this.emailAddress = emailAddress;
            this.changedFields = changedFields.add("emailAddress");
            return this;
        }

        public Builder type(AttendeeType type) {
            this.type = type;
            this.changedFields = changedFields.add("type");
            return this;
        }

        public AttendeeBase build() {
            AttendeeBase _x = new AttendeeBase();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.attendeeBase";
            _x.emailAddress = emailAddress;
            _x.type = type;
            return _x;
        }
    }

    private AttendeeBase _copy() {
        AttendeeBase _x = new AttendeeBase();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.emailAddress = emailAddress;
        _x.type = type;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AttendeeBase[");
        b.append("emailAddress=");
        b.append(this.emailAddress);
        b.append(", ");
        b.append("type=");
        b.append(this.type);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
